/*
** Gets an interface request structure and stores the acquired data
** into an if_s structure (ifname, MAC, IP(DQN string/hex string)).
**
** Copyright (C) 2004  Moreno 'baro' Baricevic
**                                      <baro AT democritos DOT it>
**
** This  file may be used subject to the terms and conditions of the
** GNU Library General Public License as published by the Free Soft-
** ware Foundation; either version 2 of the License, or (at your op-
** tion) any later version.
**
** This file is distributed in the hope that it will be useful,  but
** WITHOUT  ANY  WARRANTY; without even the implied warranty of MER-
** CHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Li-
** brary General Public License for more details.
*/

/**************************************************
 * Author: Moreno "Baro" Baricevic                *
 * Date:   04 May 2004                            *
 * Title:  iface.c                                *
 *================================================*
 * Last Modified: 04 May 2004                     *
 **************************************************/


#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include "iface.h"


/*****************************************************************************
 *_____________________________  GET_IFACE_INFO _____________________________*
 *****************************************************************************/
int
get_iface_info ( sock , iface , buf )
   int sock;
   const char * iface;
   if_s * buf;
{
   struct ifreq ifreq;
   struct sockaddr_in *saptr = NULL;

   /* store iface name */
   snprintf( buf->iface , IF_NAMESIZE , "%s" , iface );

   /* copy in the interface name to look up address of */
   strncpy( ifreq.ifr_name , iface , IF_NAMESIZE );

   /* get the address for this interface */
   if( ioctl( sock , SIOCGIFADDR , &ifreq ) != 0 )
   {
      fprintf( stderr
               , "ioctl failed on SIOCGIFADDR for device '%s': [%d] %m\n"
               , iface , errno
             );
      return -1 ;
   }

   saptr = (struct sockaddr_in *)&ifreq.ifr_addr;

   /* store iface IP addr (Decimal Quad Notation) */
   snprintf( buf->ip , IP_LEN
             , "%u.%u.%u.%u"
             , NIPQUAD( saptr->sin_addr.s_addr )
           );

   /* store iface IP addr (hexadecimal (tftp,pxe,...)) */
   snprintf( buf->ipx , IPX_LEN
             , "%02X%02X%02X%02X"
             , NIPQUAD( saptr->sin_addr.s_addr )
           );

   /*
   ** get the MAC address for this interface
   */
   if ( ioctl( sock , SIOCGIFHWADDR , &ifreq ) < 0 )
   {
      fprintf( stderr
               , "ioctl failed on SIOCGIFHWADDR for device '%s': [%d] %m\n"
               , iface , errno
             );
      return -1 ;
   }

   /* store iface MAC address */
   snprintf( buf->mac , MAC_LEN ,
             "%02X:%02X:%02X:%02X:%02X:%02X"
             , 0[ifreq.ifr_hwaddr.sa_data] & 0xff
             , 1[ifreq.ifr_hwaddr.sa_data] & 0xff
             , 2[ifreq.ifr_hwaddr.sa_data] & 0xff
             , 3[ifreq.ifr_hwaddr.sa_data] & 0xff
             , 4[ifreq.ifr_hwaddr.sa_data] & 0xff
             , 5[ifreq.ifr_hwaddr.sa_data] & 0xff
           );

   return 0;

} /* get_iface_info */




/***********************  E N D   O F   F I L E  ************************/

