/*
** List info about a network interface (iface name given by cmdline).
**
** Copyright (C) 2004  Moreno 'baro' Baricevic
**                                      <baro AT democritos DOT it>
**
** This  file may be used subject to the terms and conditions of the
** GNU Library General Public License as published by the Free Soft-
** ware Foundation; either version 2 of the License, or (at your op-
** tion) any later version.
**
** This file is distributed in the hope that it will be useful,  but
** WITHOUT  ANY  WARRANTY; without even the implied warranty of MER-
** CHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Li-
** brary General Public License for more details.
*/

/**************************************************
 * Author: Moreno "Baro" Baricevic                *
 * Date:   04 May 2004                            *
 * Title:  iface_info.c                           *
 *================================================*
 * Last Modified: 04 May 2004                     *
 **************************************************/

#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include "iface.h"


/************
 *   MAIN   *
 ************/
int main ( int argc , char * argv[] )
{
   if_s output;
   int retval = 0;

   int sock = socket( AF_INET , SOCK_STREAM , 0 );
   if ( sock < 0 )
   {
      fprintf( stderr , "socket failed: [%d] %m\n" , errno );
      return -1 ;
   }

   if ( argc != 2 || ! *argv[1] )
   {
      fprintf( stderr ,
               "Usage: %s NET_INTERFACE_NAME\n"
               "       %s eth0\n"
               , argv[0] , argv[0]
             );
      exit( -1 );
   }

   // initialize fields
   memset( &output , 0 , sizeof( if_s ) );
   *output.iface = *output.mac = *output.ip = *output.ipx = EMPTY_CH;

   retval = get_iface_info( sock , argv[1] , &output );

   printf( "%s%c%s%c%s%c%s\n"
           , output.iface	, SEP_CH
           , output.mac		, SEP_CH
           , output.ip		, SEP_CH
           , output.ipx
         );

   close( sock );

   return( !!retval );

} /* main */




/***********************  E N D   O F   F I L E  ************************/

