/*
** List info about each configured network interface or given
** interface name.
**
** Copyright (C) 2004  Moreno 'baro' Baricevic
**                                      <baro AT democritos DOT it>
**
** This  file may be used subject to the terms and conditions of the
** GNU Library General Public License as published by the Free Soft-
** ware Foundation; either version 2 of the License, or (at your op-
** tion) any later version.
**
** This file is distributed in the hope that it will be useful,  but
** WITHOUT  ANY  WARRANTY; without even the implied warranty of MER-
** CHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Li-
** brary General Public License for more details.
*/

/**************************************************
 * Author: Moreno "Baro" Baricevic                *
 * Date:   04 May 2004                            *
 * Title:  ifinfo.c                               *
 *================================================*
 * Last Modified: 04 May 2004                     *
 **************************************************/

#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include "iface.h"


struct if_nameindex if_dummy;

int all = 0;


/********************************************************************
 *_____________________________  USAGE _____________________________*
 ********************************************************************/
static void Usage ( const char * p )
{
   fprintf( stderr ,
            "Usage: %s [ NET_INTERFACE_NAME | -a ]\n"
            "       %s eth0\n"
            "       %s -a\n"
            , p , p , p
          );
   exit( -1 );
} /* Usage */



/************************************************************************
 *_____________________________  PARSE_OPT _____________________________*
 ************************************************************************/
static void parse_opt ( int c , char * v[] )
{

   if ( c != 2 || ! *v[1] )
     Usage( v[0] );

   if ( v[1][0] == '-' )
   {
      if ( ( v[1][1] == 'a' || v[1][1] == 'l' ) && ! v[1][2] )
        all = 1;
      else
        Usage( v[0] );
   }
   else
     if_dummy.if_index = 1 , if_dummy.if_name = v[1];

} /* parse_opt */



/************
 *   MAIN   *
 ************/
int main ( int argc , char * argv[] )
{
   if_s output;
   int retval = 0;
   struct if_nameindex *iflist = NULL, *listsave = NULL;
   int sock = -1;


   parse_opt( argc , argv );


   sock = socket( AF_INET , SOCK_STREAM , 0 );
   if ( sock < 0 )
   {
      fprintf( stderr , "socket failed: [%d] %m\n" , errno );
      return -1 ;
   }


   if ( all )
     iflist = listsave = if_nameindex();
   else
     iflist = &if_dummy;


   for ( ; *(char *)iflist != 0 ; iflist++ )
   {

      // (re)initialize fields
      memset( &output , 0 , sizeof( if_s ) );
      *output.iface = *output.mac = *output.ip = *output.ipx = EMPTY_CH;

      retval += get_iface_info( sock , iflist->if_name , &output );

      printf( "%s%c%s%c%s%c%s\n"
              , output.iface       , SEP_CH
              , output.mac         , SEP_CH
              , output.ip          , SEP_CH
              , output.ipx
            );

   }


   if ( all )
     if_freenameindex( listsave );


   close( sock );


   return( !!retval );

} /* main */




/***********************  E N D   O F   F I L E  ************************/

